@@ -183,10 +183,19 @@ class S3Storage(BaseStorage):
                 use_ssl=self._settings.get('S3CONF_S3_USE_SSL') or self._settings.get('AWS_S3_USE_SSL', True),
                 endpoint_url=self._settings.get('S3CONF_S3_ENDPOINT_URL') or self._settings.get('AWS_S3_ENDPOINT_URL'),
             )  # yapf: disable
+
             signature_version = (self._settings.get('S3CONF_S3_SIGNATURE_VERSION')
                                  or self._settings.get('AWS_S3_SIGNATURE_VERSION'))
+            pool_connections = self._settings.get('AWS_S3_MAX_POOL_CONNECTIONS')
+
+            botoconfig = {}
             if signature_version:
-                resource_kwargs['config'] = botocore__Config(signature_version=signature_version)
+                botoconfig['signature_version'] = signature_version
+            if pool_connections:
+                botoconfig['max_pool_connections'] = int(pool_connections)
+
+            if botoconfig:
+                resource_kwargs['config'] = botocore__Config(**botoconfig)
             self._resource = boto3.resource('s3', **resource_kwargs)
         return self._resource
 
@@ -320,21 +329,23 @@ class S3Storage(BaseStorage):
         else:
             return s3_file.e_tag
 
-    def url(self, name: str):
+    def url(self, name: str, check_for_inexistent=True) -> str:
         """
         Returns the URL where the contents of the file referenced by name can be accessed.
         This can raise NotImplementedError depending on the backend used.
         """
         internal_name = self.get_valid_name(name)
         s3_file = self.s3.Object(self._bucket_name, self._normalize_name(internal_name))
-        try:
-            # See if the resource exists
-            s3_file.e_tag
-        except ClientError as err:
-            err_msg = str(err)
-            if '404' in err_msg and 'Not Found' in err_msg:
-                return None
-            raise
+
+        if check_for_inexistent:
+            try:
+                # See if the resource exists
+                s3_file.e_tag
+            except ClientError as err:
+                err_msg = str(err)
+                if '404' in err_msg and 'Not Found' in err_msg:
+                    return None
+                raise
 
         url = self.s3.meta.client.generate_presigned_url(
             'get_object',
